import combiningPrefix from './combiningPrefix'

it('should exist', () => {
  expect(combiningPrefix).toBeDefined()
})

it('should be a callable', () => {
  expect(typeof combiningPrefix).toBe('function')
})

it('should accept 4 arguments', () => {
  expect(combiningPrefix).toHaveLength(4)
})

describe('on 0 in hundreds place', () => {
  describe('on 0 in tens place', () => {
    test.each`
      value | display | name
      ${1}  | ${'1'}  | ${'mi'}
      ${2}  | ${'2'}  | ${'bi'}
      ${3}  | ${'3'}  | ${'tri'}
      ${4}  | ${'4'}  | ${'kuwadri'}
      ${5}  | ${'5'}  | ${'kuwinti'}
      ${6}  | ${'6'}  | ${'seksti'}
      ${7}  | ${'7'}  | ${'septi'}
      ${8}  | ${'8'}  | ${'okti'}
      ${9}  | ${'9'}  | ${'noni'}
    `('should return "$name" on $display', ({ value, name, }) => {
      expect(combiningPrefix(0, 0, value)).toBe(name)
    })
  })

  describe.each`
    tens | tensName
    ${1} | ${'desi'}
    ${2} | ${'bihinti'}
    ${3} | ${'trihinti'}
    ${4} | ${'kuwadrahinti'}
    ${5} | ${'kuwinkuwahinti'}
    ${6} | ${'seksahinti'}
    ${7} | ${'septuwahinti'}
    ${8} | ${'oktohinti'}
    ${9} | ${'nonahinti'}
  `('on $tens in tens place', ({ tens, tensName, }) => {
    test.each`
      ones | display
      ${0} | ${tensName}
      ${1} | ${'un' + tensName}
      ${2} | ${'duwo' + tensName}
      ${3} | ${'tre' + tensName}
      ${4} | ${'kuwatuwor' + tensName}
      ${5} | ${'kuwin' + tensName}
      ${6} | ${'seks' + tensName}
      ${7} | ${'septen' + tensName}
      ${8} | ${'okto' + tensName}
      ${9} | ${'nobem' + tensName}
    `(`should return "$display" for ${tens}$ones`, ({ ones, display, }) => {
      expect(combiningPrefix(0, tens, ones)).toBe(display)
    })
  })
})

describe.each`
  hundreds | hundredsName
  ${1}     | ${'sen'}
  ${2}     | ${'duwosen'}
  ${3}     | ${'tresen'}
  ${4}     | ${'kuwadringhen'}
  ${5}     | ${'kuwinghen'}
  ${6}     | ${'sesen'}
  ${7}     | ${'septinghen'}
  ${8}     | ${'oktinghen'}
  ${9}     | ${'nonghen'}
`('on $hundreds in hundreds place', ({ hundreds, hundredsName, }) => {
  describe.each`
    tens | tensName
    ${0} | ${'ti'}
    ${1} | ${'desi'}
    ${2} | ${'bihinti'}
    ${3} | ${'trihinti'}
    ${4} | ${'kuwadrahinti'}
    ${5} | ${'kuwinkuwahinti'}
    ${6} | ${'seksahinti'}
    ${7} | ${'septuwahinti'}
    ${8} | ${'oktohinti'}
    ${9} | ${'nonahinti'}
  `('on $tens in tens place', ({ tens, tensName, }) => {
    test.each`
      ones | display
      ${0} | ${hundredsName + tensName}
      ${1} | ${hundredsName + 'un' + tensName}
      ${2} | ${hundredsName + 'duwo' + tensName}
      ${3} | ${hundredsName + 'tre' + tensName}
      ${4} | ${hundredsName + 'kuwatuwor' + tensName}
      ${5} | ${hundredsName + 'kuwin' + tensName}
      ${6} | ${hundredsName + 'seks' + tensName}
      ${7} | ${hundredsName + 'septen' + tensName}
      ${8} | ${hundredsName + 'okto' + tensName}
      ${9} | ${hundredsName + 'nobem' + tensName}
    `(`should return "$display" for ${hundreds}${tens}$ones`, ({ ones, display, }) => {
      expect(combiningPrefix(hundreds, tens, ones)).toBe(display)
    })
  })
})

describe.each`
  hundredThousands | hundredThousandsName
  ${1}             | ${'sen'}
  ${2}             | ${'duwosen'}
  ${3}             | ${'tresen'}
  ${4}             | ${'kuwadringhen'}
  ${5}             | ${'kuwinghen'}
  ${6}             | ${'sesen'}
  ${7}             | ${'septinghen'}
  ${8}             | ${'oktinghen'}
  ${9}             | ${'nonghen'}
`('on $hundredThousands in hundred thousands place', ({ hundredThousands, hundredThousandsName, }) => {
  describe.each`
    tenThousands | tenThousandsName
    ${0}         | ${''}
    ${1}         | ${'des'}
    ${2}         | ${'bihin'}
    ${3}         | ${'trihin'}
    ${4}         | ${'kuwadrahin'}
    ${5}         | ${'kuwinkuwahin'}
    ${6}         | ${'seksahin'}
    ${7}         | ${'septuwahin'}
    ${8}         | ${'oktohin'}
    ${9}         | ${'nonahin'}
  `('on $tenThousands in ten thousands place', ({ tenThousands, tenThousandsName, }) => {
    test.each`
      thousands | display                                          | name
      ${0}      | ${hundredThousands + '' + tenThousands + '0000'} | ${hundredThousandsName + tenThousandsName + 'milyati'}
      ${1000}   | ${hundredThousands + '' + tenThousands + '1000'} | ${hundredThousandsName + 'un' + tenThousandsName + 'milyati'}
      ${2000}   | ${hundredThousands + '' + tenThousands + '2000'} | ${hundredThousandsName + 'duwo' + tenThousandsName + 'milyati'}
      ${3000}   | ${hundredThousands + '' + tenThousands + '3000'} | ${hundredThousandsName + 'tre' + tenThousandsName + 'milyati'}
      ${4000}   | ${hundredThousands + '' + tenThousands + '4000'} | ${hundredThousandsName + 'kuwatuwor' + tenThousandsName + 'milyati'}
      ${5000}   | ${hundredThousands + '' + tenThousands + '5000'} | ${hundredThousandsName + 'kuwin' + tenThousandsName + 'milyati'}
      ${6000}   | ${hundredThousands + '' + tenThousands + '6000'} | ${hundredThousandsName + 'seks' + tenThousandsName + 'milyati'}
      ${7000}   | ${hundredThousands + '' + tenThousands + '7000'} | ${hundredThousandsName + 'septen' + tenThousandsName + 'milyati'}
      ${8000}   | ${hundredThousands + '' + tenThousands + '8000'} | ${hundredThousandsName + 'okto' + tenThousandsName + 'milyati'}
      ${9000}   | ${hundredThousands + '' + tenThousands + '9000'} | ${hundredThousandsName + 'nobem' + tenThousandsName + 'milyati'}
    `(`should return "$name" for $display`, ({ thousands, name, }) => {
      const kiloHundreds = (
        hundredThousands * 1000
        + tenThousands * 100
        + thousands / 100
      )
      expect(combiningPrefix(
        kiloHundreds,
        0,
        0,
      )).toBe(name)
    })
  })
})

it.each`
  value | display      | name
  ${1}  | ${'1000000'} | ${'milyamilyati'}
  ${2}  | ${'2000000'} | ${'duwomilyamilyati'}
  ${3}  | ${'3000000'} | ${'tremilyamilyati'}
  ${4}  | ${'4000000'} | ${'kuwatuwormilyamilyati'}
  ${5}  | ${'5000000'} | ${'kuwinmilyamilyati'}
  ${6}  | ${'6000000'} | ${'seksmilyamilyati'}
  ${7}  | ${'7000000'} | ${'septenmilyamilyati'}
  ${8}  | ${'8000000'} | ${'oktomilyamilyati'}
  ${9}  | ${'9000000'} | ${'nobemmilyamilyati'}
`('should return "$name" on $display', ({ value, name, }) => {
  expect(combiningPrefix(value * 10000, 0, 0)).toBe(name)
})

it.each`
  value | display      | name
  ${1}  | ${'1001000'} | ${'milyamilyaunmilyati'}
  ${2}  | ${'2002000'} | ${'duwomilyamilyaduwomilyati'}
  ${3}  | ${'3003000'} | ${'tremilyamilyatremilyati'}
  ${4}  | ${'4004000'} | ${'kuwatuwormilyamilyakuwatuwormilyati'}
  ${5}  | ${'5005000'} | ${'kuwinmilyamilyakuwinmilyati'}
  ${6}  | ${'6006000'} | ${'seksmilyamilyaseksmilyati'}
  ${7}  | ${'7007000'} | ${'septenmilyamilyaseptenmilyati'}
  ${8}  | ${'8008000'} | ${'oktomilyamilyaoktomilyati'}
  ${9}  | ${'9009000'} | ${'nobemmilyamilyanobemmilyati'}
`('should return "$name" on $display', ({ value, name, }) => {
  expect(combiningPrefix(value * 10010, 0, 0)).toBe(name)
})

